==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/GeographicTileSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TileSeries } from "./TileSeries";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { runOn, delegateRemove, delegateCombine, markType } from "igniteui-webcomponents-core";
import { ImageTilesReadyEventArgs } from "./ImageTilesReadyEventArgs";
/**
 * @hidden
 */
var GeographicTileSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicTileSeries, _super);
    function GeographicTileSeries() {
        var _this = _super.call(this) || this;
        _this.vc = null;
        _this.vb = null;
        _this.imageTilesReady = null;
        _this.ab = GeographicTileSeries.$;
        return _this;
    }
    GeographicTileSeries.prototype.bc = function () {
        return new GeographicTileSeries();
    };
    GeographicTileSeries.prototype.get_fh = function () {
        return true;
    };
    Object.defineProperty(GeographicTileSeries.prototype, "vd", {
        get: function () {
            return this.vc;
        },
        set: function (a) {
            var b = a != this.vd;
            if (b) {
                var c = this.vd;
                this.vc = a;
                this.raisePropertyChanged("TileImagery", c, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    GeographicTileSeries.prototype.vh = function () {
        if (this.vd != null) {
            this.vd.clearTileCache();
        }
    };
    GeographicTileSeries.prototype.pa = function (a, b, c, d) {
        _super.prototype.pa.call(this, a, b, c, d);
        switch (b) {
            case "TileImagery":
                if (this.t5 != null) {
                    this.t5.wy = this.vd;
                }
                break;
        }
    };
    GeographicTileSeries.prototype.ua = function () {
        _super.prototype.ua.call(this);
        this.t5.wy = this.vd;
        if (this.vb != null) {
            var a = this.vb;
            a.imageTilesReady = delegateRemove(a.imageTilesReady, runOn(this, this.vg));
        }
        this.vb = this.t5;
        if (this.vb != null) {
            var b = this.vb;
            b.imageTilesReady = delegateCombine(b.imageTilesReady, runOn(this, this.vg));
        }
    };
    GeographicTileSeries.prototype.t4 = function () {
        return new TileSeries();
    };
    GeographicTileSeries.prototype.vg = function (a, b) {
        if (this.imageTilesReady != null) {
            this.imageTilesReady(this, new ImageTilesReadyEventArgs());
        }
    };
    GeographicTileSeries.$t = markType(GeographicTileSeries, 'GeographicTileSeries', GeographicShapeSeriesBase.$);
    return GeographicTileSeries;
}(GeographicShapeSeriesBase));
export { GeographicTileSeries };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/GeographicTileSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TileSeries } from "./TileSeries";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { runOn, delegateRemove, delegateCombine, markType } from "igniteui-webcomponents-core";
import { ImageTilesReadyEventArgs } from "./ImageTilesReadyEventArgs";
/**
 * @hidden
 */
var GeographicTileSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicTileSeries, _super);
    function GeographicTileSeries() {
        var _this = _super.call(this) || this;
        _this.yi = null;
        _this.yh = null;
        _this.imageTilesReady = null;
        _this.ab = GeographicTileSeries.$;
        return _this;
    }
    GeographicTileSeries.prototype.bk = function () {
        return new GeographicTileSeries();
    };
    GeographicTileSeries.prototype.get_f3 = function () {
        return true;
    };
    Object.defineProperty(GeographicTileSeries.prototype, "yj", {
        get: function () {
            return this.yi;
        },
        set: function (a) {
            var b = a != this.yj;
            if (b) {
                var c = this.yj;
                this.yi = a;
                this.raisePropertyChanged("TileImagery", c, a);
            }
        },
        enumerable: false,
        configurable: true
    });
    GeographicTileSeries.prototype.yn = function () {
        if (this.yj != null) {
            this.yj.clearTileCache();
        }
    };
    GeographicTileSeries.prototype.ra = function (a, b, c, d) {
        _super.prototype.ra.call(this, a, b, c, d);
        switch (b) {
            case "TileImagery":
                if (this.w2 != null) {
                    this.w2.aad = this.yj;
                }
                break;
        }
    };
    GeographicTileSeries.prototype.w7 = function (a, b) {
        _super.prototype.w7.call(this, a, b);
        this.w2.aad = this.yj;
        if (this.yh != null) {
            var c = this.yh;
            c.imageTilesReady = delegateRemove(c.imageTilesReady, runOn(this, this.ym));
        }
        this.yh = this.w2;
        if (this.yh != null) {
            var d = this.yh;
            d.imageTilesReady = delegateCombine(d.imageTilesReady, runOn(this, this.ym));
        }
    };
    GeographicTileSeries.prototype.w1 = function () {
        return new TileSeries();
    };
    GeographicTileSeries.prototype.ym = function (a, b) {
        if (this.imageTilesReady != null) {
            this.imageTilesReady(this, new ImageTilesReadyEventArgs());
        }
    };
    GeographicTileSeries.$t = markType(GeographicTileSeries, 'GeographicTileSeries', GeographicShapeSeriesBase.$);
    return GeographicTileSeries;
}(GeographicShapeSeriesBase));
export { GeographicTileSeries };
